"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = require("path");
const typescript_1 = require("typescript");
const commentsJson = require("comment-json");
const findUp = require("find-up");
const fs_1 = require("../utils/fs");
const configCache = {};
function loadConfiguration(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const cached = Object.keys(configCache).find(cachePath => path.indexOf(cachePath) === 0);
        if (cached) {
            return configCache[cached];
        }
        const cwd = path_1.dirname(path);
        const configPath = yield findUp('tsconfig.json', { cwd });
        if (!configPath) {
            throw new Error('Cannot find tsconfig');
        }
        const tsconfig = configPath && commentsJson.parse(yield fs_1.readFile(configPath));
        const transpilerOptions = {
            compilerOptions: {
                module: 'es2015',
                moduleResolution: 'node'
            }
        };
        // Overwrite default if config is found
        if (tsconfig) {
            transpilerOptions.compilerOptions = Object.assign({}, transpilerOptions.compilerOptions, tsconfig.compilerOptions);
            transpilerOptions.files = tsconfig.files;
            transpilerOptions.include = tsconfig.include;
            transpilerOptions.exclude = tsconfig.exclude;
        }
        const { typeRoots } = transpilerOptions.compilerOptions;
        if (typeRoots && Array.isArray(typeRoots)) {
            transpilerOptions.include = [
                ...(transpilerOptions.include || []),
                ...typeRoots.map((root) => `${root.replace(/(\/|\\)*$/, '')}/**/*`)
            ];
        }
        transpilerOptions.compilerOptions.noEmit = false;
        delete transpilerOptions.compilerOptions.outDir;
        const options = Object.assign({}, typescript_1.parseJsonConfigFileContent(transpilerOptions, typescript_1.sys, process.cwd()), { path: configPath });
        configCache[path_1.dirname(configPath)] = options;
        return options;
    });
}
exports.loadConfiguration = loadConfiguration;
//# sourceMappingURL=config-loader.js.map